# Welcome to **tvopt** [![Documentation Status](https://readthedocs.org/projects/tvopt/badge/?version=latest)](https://tvopt.readthedocs.io/en/latest/?badge=latest)
[**Docs**](https://tvopt.readthedocs.io/en/latest/)
| [**Installation**](#installation)
| [**Cite**](#cite)

**tvopt** is a prototyping and benchmarking Python framework for time-varying (or online) optimization. The framework is modular,
and provides different tools for modeling dynamic optimization problems and to solve them with a wide range of well known
algorithms.

The documentation is available [here](https://tvopt.readthedocs.io/en/latest/).
 

## Installation
**tvopt** works on Python 3.7 and depends on: numpy, scipy.

### pip installation
```
pip install tvopt
```

## Cite

```
@article{bastianello_tvopt_2020,
	title = {tvopt: {A} {Python} {Framework} for {Time}-{Varying} {Optimization}},
	url = {http://arxiv.org/abs/2011.07119},
	journal = {arXiv:2011.07119 [cs, math]},
	author = {Bastianello, Nicola},
	year = {2020}
}

```

## Author
**tvopt** is developed by
[Nicola Bastianello](https://nicola-bastianello.github.io)
